# Changelog

## 0.3.0 (2024-04-30)

- Use the Cryptography package to serialize PKCS12 files. Drop
  pyOpenSSL < 24.1.0 requirement. Thanks, @zent1n0!

## 0.2.1 (2024-04-30)

- Require pyOpenSSL < 24.1.0 because that version removed PKCS12 support.

## 0.2.0 (2022-05-05)

- Switch from cryptography to pyOpenSSL.

## 0.1.0 (2022-05-05)

- First release.
